pub enum ImageCompareFunction {
Never,
Less,
Equal,
LessEqual,
Greater,
NotEqual,
GreaterEqual,
Always,
}Expand description
Comparison function used for depth and stencil operations.
This type mirrors CompareFunction.
Variants
Never
Function never passes
Less
Function passes if new value less than existing value
Equal
Function passes if new value is equal to existing value. When using
this compare function, make sure to mark your Vertex Shader’s @builtin(position)
output as @invariant to prevent artifacting.
LessEqual
Function passes if new value is less than or equal to existing value
Greater
Function passes if new value is greater than existing value
NotEqual
Function passes if new value is not equal to existing value. When using
this compare function, make sure to mark your Vertex Shader’s @builtin(position)
output as @invariant to prevent artifacting.
GreaterEqual
Function passes if new value is greater than or equal to existing value
Always
Function always passes