pub enum ImageFilterMode {
Nearest,
Linear,
}Expand description
Texel mixing mode when sampling between texels.
This type mirrors FilterMode.
Variants
Nearest
Nearest neighbor sampling.
This creates a pixelated effect when used as a mag filter.
Linear
Linear Interpolation.
This makes textures smooth but blurry when used as a mag filter.