pub enum ImageSampler {
Default,
Descriptor(ImageSamplerDescriptor),
}Expand description
Used in Image, this determines what image sampler to use when rendering. The default setting,
ImageSampler::Default, will read the sampler from the ImagePlugin at setup.
Setting this to ImageSampler::Descriptor will override the global default descriptor for this Image.
Variants
Default
Default image sampler, derived from the ImagePlugin setup.
Descriptor(ImageSamplerDescriptor)
Custom sampler for this image which will override global default.
Implementations
Sourceimpl ImageSampler
impl ImageSampler
Sourcepub fn linear() -> ImageSampler
pub fn linear() -> ImageSampler
Returns an image sampler with ImageFilterMode::Linear min and mag filters
Sourcepub fn nearest() -> ImageSampler
pub fn nearest() -> ImageSampler
Returns an image sampler with ImageFilterMode::Nearest min and mag filters
Sourcepub fn get_or_init_descriptor(&mut self) -> &mut ImageSamplerDescriptor
pub fn get_or_init_descriptor(&mut self) -> &mut ImageSamplerDescriptor
Initialize the descriptor if it is not already initialized.
Descriptor is typically initialized by Bevy when the image is loaded, so this is convenient shortcut for updating the descriptor.