TextureAccessError

Enum TextureAccessError 

pub enum TextureAccessError {
    OutOfBounds {
        x: u32,
        y: u32,
        z: u32,
    },
    UnsupportedTextureFormat(TextureFormat),
    Uninitialized,
    WrongDimension,
}
An error that occurs when accessing specific pixels in a texture.

Variants



OutOfBounds

Attempted to access a pixel outside the texture bounds.

Fields

x: u32

The pixel x-coordinate.

y: u32

The pixel y-coordinate.

z: u32

The pixel z-coordinate.



UnsupportedTextureFormat(TextureFormat)

Attempted to perform an image operation on an unsupported texture format.

Most often this is returned when attempting to access pixel data of compressed textures.



Uninitialized

Attempted to access the data of an image before it was initialized, or after it was moved to the GPU.

See RenderAssetUsages for more information about when an asset’s data is moved, and how to retain it if necessary.



WrongDimension

The texture’s dimension was different than indicated by the accessor used.