pub enum TextureReinterpretationError {
IncompatibleSizes {
old: Extent3d,
new: Extent3d,
},
WrongDimension,
NotEnoughLayers,
InvalidLayerCount,
HeightNotDivisibleByLayers {
height: u32,
layers: u32,
},
GridHeightNotDivisibleByTileHeight {
height: u32,
tile_count_y: u32,
},
GridWidthNotDivisibleByTileWidth {
width: u32,
tile_count_x: u32,
},
InvalidTextureFormat,
}Expand description
An error that occurs when reinterpreting an image.
Variants
IncompatibleSizes
The pixel volumes of the original and reinterpreted extents were different.
WrongDimension
The image was expected to be 2d.
NotEnoughLayers
In a texture 2d array, there needs to be at least 2 layers or else a render validation error will be throw.
InvalidLayerCount
The image was expected to have a single layer.
HeightNotDivisibleByLayers
The stacked image could not be evenly divided into the desired number of image layers.
GridHeightNotDivisibleByTileHeight
The grid height is not divisible by the number of tiles in the height.
Fields
GridWidthNotDivisibleByTileWidth
The grid width is not divisible by the number of tiles in the width.
Fields
InvalidTextureFormat
The texture format is not supported.