pub struct CompressedImageFormats(/* private fields */);Expand description
A set of flags describing the compressed formats supported by a render device.
Implementations
Sourceimpl CompressedImageFormats
impl CompressedImageFormats
Sourcepub const ASTC_LDR: Self
pub const ASTC_LDR: Self
Support for Adaptive Scalable Texture Compression.
For more information see:
Sourcepub const BC: Self
pub const BC: Self
Support for Block Compressed textures.
For more information see:
Features::TEXTURE_COMPRESSION_BC- S3TC Format Specification (BC1, BC2, BC3)
- RGTC Format Specification (BC4, BC5)
- BPTC Format Specification (BC6, BC7)
Sourceimpl CompressedImageFormats
impl CompressedImageFormats
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl CompressedImageFormats
impl CompressedImageFormats
Sourcepub const fn iter(&self) -> Iter<CompressedImageFormats>
pub const fn iter(&self) -> Iter<CompressedImageFormats>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<CompressedImageFormats>
pub const fn iter_names(&self) -> IterNames<CompressedImageFormats>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl CompressedImageFormats
impl CompressedImageFormats
Sourcepub fn from_features(features: Features) -> Self
pub fn from_features(features: Features) -> Self
Get the supported texture compression formats from a wgpu device’s features.
Sourcepub fn supports(&self, format: TextureFormat) -> bool
pub fn supports(&self, format: TextureFormat) -> bool
Returns true if the given TextureFormat is supported by the available compression
features.
Always returns true for uncompressed formats.