ImageSamplerDescriptor

Struct ImageSamplerDescriptor 

pub struct ImageSamplerDescriptor {
    pub label: Option<String>,
    pub address_mode_u: ImageAddressMode,
    pub address_mode_v: ImageAddressMode,
    pub address_mode_w: ImageAddressMode,
    pub mag_filter: ImageFilterMode,
    pub min_filter: ImageFilterMode,
    pub mipmap_filter: ImageFilterMode,
    pub lod_min_clamp: f32,
    pub lod_max_clamp: f32,
    pub compare: Option<ImageCompareFunction>,
    pub anisotropy_clamp: u16,
    pub border_color: Option<ImageSamplerBorderColor>,
}
Indicates to an ImageLoader how an Image should be sampled.

As this type is part of the ImageLoaderSettings, it will be serialized to an image asset .meta file which might require a migration in case of a breaking change.

This types mirrors SamplerDescriptor, but that might change in future versions.

Fields

label: Option<String>

An optional label used to identify this sampler in logs.

address_mode_u: ImageAddressMode

How to deal with out of bounds accesses in the u (i.e. x) direction.

address_mode_v: ImageAddressMode

How to deal with out of bounds accesses in the v (i.e. y) direction.

address_mode_w: ImageAddressMode

How to deal with out of bounds accesses in the w (i.e. z) direction.

mag_filter: ImageFilterMode

How to filter the texture when it needs to be magnified (made larger).

min_filter: ImageFilterMode

How to filter the texture when it needs to be minified (made smaller).

mipmap_filter: ImageFilterMode

How to filter between mip map levels

lod_min_clamp: f32

Minimum level of detail (i.e. mip level) to use.

lod_max_clamp: f32

Maximum level of detail (i.e. mip level) to use.

compare: Option<ImageCompareFunction>

If this is enabled, this is a comparison sampler using the given comparison function.

anisotropy_clamp: u16

Must be at least 1. If this is not 1, all filter modes must be linear.

border_color: Option<ImageSamplerBorderColor>

Border color to use when address_mode is ImageAddressMode::ClampToBorder.

Implementations

Source

impl ImageSamplerDescriptor

pub fn linear() -> ImageSamplerDescriptor

Returns a sampler descriptor with Linear min and mag filters

pub fn nearest() -> ImageSamplerDescriptor

Returns a sampler descriptor with Nearest min and mag filters

pub fn set_filter(&mut self, filter: ImageFilterMode) -> &mut Self

Returns this sampler descriptor with a new ImageFilterMode min, mag, and mipmap filters

pub fn set_address_mode(&mut self, address_mode: ImageAddressMode) -> &mut Self

Returns this sampler descriptor with a new ImageAddressMode for u, v, and w

pub fn set_anisotropic_filter(&mut self, anisotropy_clamp: u16) -> &mut Self

Returns this sampler descriptor with an anisotropy_clamp value and also set filters to ImageFilterMode::Linear, which is required to use anisotropy.

pub fn as_wgpu(&self) -> SamplerDescriptor<Option<&str>>

Converts this sampler to its wgpu equivalent.